@@ -1,9 +1,10 @@
 #![feature(try_trait_v2)]
 
+pub use wasmy_macros::{wasm_handle, wasm_onload};
+
 pub use abi::*;
 pub use types::*;
 pub use wasm::*;
-pub use wasmy_macros::wasm_handler;
 
 pub mod abi;
 pub mod types;
@@ -13,8 +14,11 @@ mod wasm;
 pub struct WasmHandlerAPI();
 
 impl WasmHandlerAPI {
+    pub const fn onload_symbol() -> &'static str {
+        "_wasm_onload"
+    }
     pub fn method_to_symbol(method: Method) -> String {
-        format!("_wasm_handler_{}", method)
+        format!("_wasm_handle_{}", method)
     }
     pub fn symbol_to_method(symbol: &str) -> Option<Method> {
         symbol.rsplit(|r| r == '_').next().and_then(|s| s.parse().ok())
@@ -28,12 +32,12 @@ mod tests {
     #[test]
     fn method_to_symbol() {
         let method = WasmHandlerAPI::method_to_symbol(10);
-        assert_eq!(method, "_wasm_handler_10");
+        assert_eq!(method, "_wasm_handle_10");
     }
 
     #[test]
     fn symbol_to_method() {
-        let method = WasmHandlerAPI::symbol_to_method("_wasm_handler_10");
+        let method = WasmHandlerAPI::symbol_to_method("_wasm_handle_10");
         assert_eq!(method, Some(10));
     }
 }
